﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;
using System.ComponentModel;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window,INotifyPropertyChanged
    {
        private ShapeFileFeatureLayer shapeFileFeatureLayer;

        public MainWindow()
        {
            InitializeComponent();
            DataContext = this;
        }

        private float layerTransparency;
        public float LayerTransparency
        {
            get 
            {
                if (this.layerTransparency == 0.0)
                {
                    this.layerTransparency = 255;
                }
                return this.layerTransparency; 
            }
            set 
            { 
                this.layerTransparency = value;
                ChangeFeatureLayerTransparency(value);
                OnPropertyChanged("LayerTransparency");
            }
        }

        private void WpfMap_Loaded(object sender, RoutedEventArgs e)
        {
            shapeFileFeatureLayer = new ShapeFileFeatureLayer(@"C:\Program Files (x86)\ThinkGeo\Map Suite Wpf Desktop Full Edition 6.0\Samples\CSharp Samples\SampleData\Data\Countries02.shp", ShapeFileReadWriteMode.ReadOnly);
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.Canal1;
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            LayerOverlay overlay = new LayerOverlay();
            overlay.Layers.Add("WorldLayer",shapeFileFeatureLayer);
            wpfMap1.Overlays.Add(overlay);

            wpfMap1.MapUnit = GeographyUnit.DecimalDegree;
            shapeFileFeatureLayer.Open();
            wpfMap1.CurrentExtent = shapeFileFeatureLayer.GetBoundingBox();
            wpfMap1.Refresh();
        }

        private void ChangeFeatureLayerTransparency(float transparencyValue)
        {
            if (shapeFileFeatureLayer != null)
            {
                shapeFileFeatureLayer.Transparency = transparencyValue;
                wpfMap1.Refresh();
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
        public void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
